@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2022 Synchrotron SOLEIL
+ * Copyright (C) 2003-2023 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -23,6 +23,8 @@
 
 #include "datatype99.h"
 
+#include "ccan/array_size/array_size.h"
+
 #include "hkl-binoculars.h"
 #include "hkl-binoculars-cnpy-private.h"
 #include "hkl-quaternion-private.h"
@@ -147,6 +149,10 @@ static inline struct detector_t get_detector(HklBinocularsDetectorEnum n)
                 DETECTOR(MerlinMedipix3RXQuad,
                          SHAPE(515, 515), TILING(256, 256, 3, 3, 55e-6)),
         };
+
+        if (n > ARRAY_SIZE(detectors))
+                n = 0; /* use the first detector as default */
+
         return detectors[n];
 }
 
@@ -236,6 +242,15 @@ static inline double *coordinates_rectangle(const struct shape_t *shape,
 
 }
 
+static inline void flip_z(const struct shape_t *shape, double *arr)
+{
+        int i;
+        double *z = z_coordinates(arr, *shape);
+
+        for(i=0; i<shape_size(*shape); ++i)
+                z[i] *= -1;
+}
+
 static inline double *coordinates_get_square(const struct shape_t *shape,
                                              const struct square_t *square)
 {
@@ -399,7 +414,7 @@ void hkl_binoculars_detector_2d_sixs_calibration(HklBinocularsDetectorEnum n,
                                                  double *arr,
                                                  int width, int height,
                                                  int ix0, int iy0, double sdd,
-                                                 double detrot)
+                                                 double detrot, int normalize_flag)
 {
         struct shape_t shape = SHAPE(width, height);
         double *y = y_coordinates(arr, shape);
@@ -411,7 +426,8 @@ void hkl_binoculars_detector_2d_sixs_calibration(HklBinocularsDetectorEnum n,
 
         translate_coordinates(arr, shape, dx, dy, dz);
         rotate_coordinates(arr, shape, detrot, 1, 0, 0);
-        normalize_coordinates(arr, shape);
+        if(normalize_flag)
+                normalize_coordinates(arr, shape);
 }
 
 /*****************************/
@@ -460,6 +476,7 @@ double *hkl_binoculars_detector_2d_coordinates_get(HklBinocularsDetectorEnum n)
                 of(Eiger1M, tiling){
                         arr = coordinates_get_square(&detector.shape,
                                                      &tiling->square);
+                        flip_z(&detector.shape, arr);
                 }
                 of(Ufxc, square){
                         arr = coordinates_get_square(&detector.shape,
@@ -500,7 +517,7 @@ void hkl_binoculars_detector_2d_coordinates_save(HklBinocularsDetectorEnum n,
 uint8_t *hkl_binoculars_detector_2d_mask_get(HklBinocularsDetectorEnum n)
 {
         const struct detector_t detector = get_detector(n);
-        uint8_t *arr = NULL;
+        uint8_t *arr;
 
         match(detector.type){
                 of(ImXpadS70, imxpad){
@@ -528,6 +545,9 @@ uint8_t *hkl_binoculars_detector_2d_mask_get(HklBinocularsDetectorEnum n)
                         arr = mask_get_tiling(&detector.shape,
                                               tiling);
                 }
+                otherwise {
+                        arr = no_mask(&detector.shape);
+                }
         }
 
         return arr;
