@@ -249,6 +249,10 @@ instance HasIniConfig 'QCustomProjection where
                                                 HklBinocularsQCustomSubProjectionEnum'QparsQperTimestamp -> Nothing
                                                 HklBinocularsQCustomSubProjectionEnum'QparQperSampleaxis -> error "expect a valid [projection] 'sampleaxis' key"
                                                 HklBinocularsQCustomSubProjectionEnum'QSampleaxisTth -> error "expect a valid [projection] 'sampleaxis' key"
+                                                HklBinocularsQCustomSubProjectionEnum'QSampleaxisTimestamp -> error "expect a valid [projection] 'sampleaxis' key"
+                                                HklBinocularsQCustomSubProjectionEnum'QxQyTimestamp -> Nothing
+                                                HklBinocularsQCustomSubProjectionEnum'QxQzTimestamp -> Nothing
+                                                HklBinocularsQCustomSubProjectionEnum'QyQzTimestamp -> Nothing
 
 
     BinocularsConfig'QCustom
@@ -422,6 +426,10 @@ overloadTimestampPath msub idx =
                    HklBinocularsQCustomSubProjectionEnum'QparsQperTimestamp -> idx
                    HklBinocularsQCustomSubProjectionEnum'QparQperSampleaxis -> DataSourcePath'Timestamp'NoTimestamp
                    HklBinocularsQCustomSubProjectionEnum'QSampleaxisTth -> DataSourcePath'Timestamp'NoTimestamp
+                   HklBinocularsQCustomSubProjectionEnum'QSampleaxisTimestamp -> idx
+                   HklBinocularsQCustomSubProjectionEnum'QxQyTimestamp -> idx
+                   HklBinocularsQCustomSubProjectionEnum'QxQzTimestamp -> idx
+                   HklBinocularsQCustomSubProjectionEnum'QyQzTimestamp -> idx
 
 overloadWaveLength :: Maybe Double -> DataSourcePath Double -> DataSourcePath Double
 overloadWaveLength ma wp = maybe wp DataSourcePath'Double'Const ma
