@@ -8,11 +8,13 @@ module BinocularsSpec
   where
 
 
+import           Control.Monad                      (forM_)
 import           Data.Aeson                         (Result (..), fromJSON,
                                                      toJSON)
 import           Data.Array.Repa.Index              (DIM2, DIM3)
 import           Data.Attoparsec.Text               (parseOnly)
 import           Data.Either                        (isRight)
+import           Data.HashMap.Lazy                  (fromList)
 import           Data.List.NonEmpty                 (NonEmpty (..))
 import           Numeric.Interval                   (singleton, (...))
 import           Numeric.Units.Dimensional.Prelude  (meter, radian, (*~))
@@ -68,11 +70,14 @@ spec = do
 
   describe "read and parse binoculars configuration" $ do
     it "deprecated inputype" $ do
-      content <- readConfig =<< Just <$> getDataFileName "data/test/config_ech6eiger.txt"
-      capabilities <- getCapabilities
-      let args = Args'QCustomProjection (Just $ ConfigRange (InputRange (120...135) :| [InputRange (137...453)]))
-      let cfg = getConfig content args capabilities
-      isRight cfg `shouldBe` True
+      forM_ [ "data/test/config_ech6eiger.txt"
+            , "data/test/config_sixs_ruche_parsing.ini"
+            ] $ \f -> do
+        content <- readConfig =<< Just <$> getDataFileName f
+        capabilities <- getCapabilities
+        let args = Args'QCustomProjection (Just $ ConfigRange (InputRange (120...135) :| [InputRange (137...453)]))
+        let cfg = getConfig content args capabilities
+        isRight cfg `shouldBe` True
 
   -- describe "read and parse binoculars Configuration" $ do
   --   it "hkl projection" $ do
